[ARVADOS-WORKBENCH2] updated: 2.1.0-429-g9cde730b

Git user git at public.arvados.org
Thu Jul 1 15:19:36 UTC 2021


Summary of changes:
 src/store/auth/auth-middleware.ts |  2 +-
 version-at-commit.sh              | 10 +++++-----
 2 files changed, 6 insertions(+), 6 deletions(-)

       via  9cde730be1dcabd9fc9bcbe59fcfb60acf59f9fd (commit)
      from  939693eea743bcb4fc74ae6de5d5d796f125ec17 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.


commit 9cde730be1dcabd9fc9bcbe59fcfb60acf59f9fd
Author: Ward Vandewege <ward at jhvc.com>
Date:   Thu Jul 1 11:18:25 2021 -0400

    The bleeding edge branch is now called 'main'.
    
    refs #17817
    
    Arvados-DCO-1.1-Signed-off-by: Ward Vandewege <ward at curii.com>

diff --git a/src/store/auth/auth-middleware.ts b/src/store/auth/auth-middleware.ts
index ce7cd5cb..9535ca2d 100644
--- a/src/store/auth/auth-middleware.ts
+++ b/src/store/auth/auth-middleware.ts
@@ -44,7 +44,7 @@ export const authMiddleware = (services: ServiceRepository): Middleware => store
                 // want to either add support for displaying/signing user
                 // agreements or get rid of self-activation.
                 // For more details, see:
-                // https://doc.arvados.org/master/admin/user-management.html
+                // https://doc.arvados.org/main/admin/user-management.html
 
                 store.dispatch(progressIndicatorActions.START_WORKING(WORKBENCH_LOADING_SCREEN));
                 services.userService.activate(user.uuid).then((user: User) => {
diff --git a/version-at-commit.sh b/version-at-commit.sh
index fc60d53e..e42b8753 100755
--- a/version-at-commit.sh
+++ b/version-at-commit.sh
@@ -14,12 +14,12 @@ devsuffix="~dev"
 #
 # 1. commit is directly tagged.  print that.
 #
 # 2. commit is on master or a development branch, the nearest tag is older
 #    than commit where this branch joins master.
 #    -> take greatest version tag in repo X.Y.Z and assign X.(Y+1).0
 #
 # 3. commit is on a release branch, the nearest tag is newer
 #    than the commit where this branch joins master.
 #    -> take nearest tag X.Y.Z and assign X.Y.(Z+1)
 
 tagged=$(git tag --points-at "$commit")
@@ -28,13 +28,13 @@ if [[ -n "$tagged" ]] ; then
     echo $tagged
 else
     # 1. get the nearest tag with 'git describe'
     # 2. get the merge base between this commit and master
     # 3. if the tag is an ancestor of the merge base,
     #    (tag is older than merge base) increment minor version
     #    else, tag is newer than merge base, so increment point version
 
     nearest_tag=$(git describe --tags --abbrev=0 --match "$versionglob" "$commit")
-    merge_base=$(git merge-base origin/master "$commit")
+    merge_base=$(git merge-base origin/main "$commit")
 
     if git merge-base --is-ancestor "$nearest_tag" "$merge_base" ; then
         # x.(y+1).0~devTIMESTAMP, where x.y.z is the newest version that does not contain $commit

-----------------------------------------------------------------------
@@ -14,12 +14,12 @@ devsuffix="~dev"
 # 1. commit is directly tagged.  print that.
 #
-# 2. commit is on master or a development branch, the nearest tag is older
-#    than commit where this branch joins master.
+# 2. commit is on main or a development branch, the nearest tag is older
+#    than commit where this branch joins main.
 #    -> take greatest version tag in repo X.Y.Z and assign X.(Y+1).0
 #
@@ -14,12 +14,12 @@ devsuffix="~dev"
 #
 # 3. commit is on a release branch, the nearest tag is newer
-#    than the commit where this branch joins master.
+#    than the commit where this branch joins main.
 #    -> take nearest tag X.Y.Z and assign X.Y.(Z+1)
 
@@ -28,13 +28,13 @@ if [[ -n "$tagged" ]] ; then
 else
     # 1. get the nearest tag with 'git describe'
-    # 2. get the merge base between this commit and master
+    # 2. get the merge base between this commit and main
     # 3. if the tag is an ancestor of the merge base,
     #    (tag is older than merge base) increment minor version


hooks/post-receive
-- 




More information about the arvados-commits mailing list